import { highlightBlock } from 'highlight.js';
import React, { useState, useRef, useLayoutEffect, useEffect } from 'react';

require('./index.css');

var CodeEditorEditable = function CodeEditorEditable(_ref) {
  var _ref$width = _ref.width,
      width = _ref$width === void 0 ? '500px' : _ref$width,
      _ref$height = _ref.height,
      height = _ref$height === void 0 ? '500px' : _ref$height,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? '0' : _ref$padding,
      _ref$borderRadius = _ref.borderRadius,
      borderRadius = _ref$borderRadius === void 0 ? '0' : _ref$borderRadius,
      value = _ref.value,
      setValue = _ref.setValue,
      language = _ref.language,
      _ref$caretColor = _ref.caretColor,
      caretColor = _ref$caretColor === void 0 ? 'red' : _ref$caretColor,
      _ref$tabSize = _ref.tabSize,
      tabSize = _ref$tabSize === void 0 ? 2 : _ref$tabSize,
      _ref$inlineNumbers = _ref.inlineNumbers,
      inlineNumbers = _ref$inlineNumbers === void 0 ? true : _ref$inlineNumbers;

  var _useState = useState(['']),
      lineNumbers = _useState[0],
      setLineNumbers = _useState[1];

  var _useState2 = useState(0),
      caretPos = _useState2[0],
      setCaretPos = _useState2[1];

  var codeBlockRef = useRef(null);
  var textAreaRef = useRef(null);
  var lineNumbersRef = useRef(null);

  var countLines = function countLines(codeString) {
    return codeString === null || codeString === void 0 ? void 0 : codeString.split(/\r*\n/);
  };

  var handleScroll = function handleScroll(e) {
    var eventTarget = e.target;

    if (codeBlockRef.current) {
      codeBlockRef.current.scroll(eventTarget.scrollLeft, eventTarget.scrollTop);

      if (inlineNumbers && lineNumbersRef.current) {
        lineNumbersRef.current.scroll(eventTarget.scrollLeft, eventTarget.scrollTop);
      }
    }
  };

  var handleChange = function handleChange(e) {
    setValue(e.target.value);
  };

  var setCaretPosition = function setCaretPosition(ctrl, pos) {
    if (ctrl.setSelectionRange) {
      ctrl.focus();
      ctrl.setSelectionRange(pos, pos);
    } else if (ctrl.createTextRange) {
      var range = ctrl.createTextRange();
      range.collapse(true);
      range.moveEnd('character', pos);
      range.moveStart('character', pos);
      range.select();
    }
  };

  var handleKeyDown = function handleKeyDown(e) {
    var myField = textAreaRef.current;
    var myValue = Math.random().toString(32).substring(0, tabSize).replace(/./g, ' ');

    if (e.key === 'Tab') {
      e.preventDefault();

      if (myField !== null && myField !== void 0 && myField.selectionStart || (myField === null || myField === void 0 ? void 0 : myField.selectionStart) === 0) {
        var startPos = myField.selectionStart;
        var endPos = myField.selectionEnd;
        setCaretPos(startPos + myValue.length);
        var newValue = myField.value.substring(0, startPos) + myValue + myField.value.substring(endPos, myField.value.length);
        setValue(newValue);
      }
    }
  };

  useLayoutEffect(function () {
    if (caretPos !== 0 && textAreaRef.current) {
      setCaretPosition(textAreaRef.current, caretPos);
      setCaretPos(0);
    }
  }, [caretPos]);
  useEffect(function () {
    if (codeBlockRef.current) {
      highlightBlock(codeBlockRef.current);
      setLineNumbers(countLines(value));
    }
  }, [value]);
  return React.createElement("div", {
    className: 'hljs container-code-editor__qxcy',
    style: {
      width: width,
      height: height,
      padding: padding,
      borderRadius: borderRadius
    }
  }, inlineNumbers && React.createElement("div", {
    className: 'hljs line-numbers__qxcy',
    ref: lineNumbersRef
  }, lineNumbers === null || lineNumbers === void 0 ? void 0 : lineNumbers.map(function (__val, key) {
    return React.createElement("div", {
      className: 'line-numbers__number__qxcy',
      key: key
    }, key + 1);
  })), React.createElement("pre", {
    className: 'code-editor__qxcy'
  }, React.createElement("code", {
    ref: codeBlockRef,
    className: "code-editor__hlcode__qxcy language-" + language
  }, value + "\n\r"), React.createElement("textarea", {
    value: value,
    spellCheck: 'false',
    ref: textAreaRef,
    className: 'hljs code-editor__textarea__qxcy',
    onScroll: handleScroll,
    onChange: handleChange,
    maxLength: 3000,
    onKeyDown: handleKeyDown,
    style: {
      msScrollbarBaseColor: 'violet',
      scrollbarWidth: 'thin',
      caretColor: caretColor
    }
  })));
};

export { CodeEditorEditable };
//# sourceMappingURL=index.modern.js.map
